pub struct Garbage {
pub base_struct: Item,
}Fields
base_struct: ItemTrait Implementations
Sourceimpl ItemSuperFn for Garbage
impl ItemSuperFn for Garbage
Sourcefn get_base_item(&self) -> &Item
fn get_base_item(&self) -> &Item
Get the item struct.
Sourcefn get_base_item_mut(&mut self) -> &mut Item
fn get_base_item_mut(&mut self) -> &mut Item
Get the mutable item struct.
Sourceimpl ObjectSuperFn for Garbage
impl ObjectSuperFn for Garbage
Sourcefn get_base_object(&self) -> &Object
fn get_base_object(&self) -> &Object
Get the object struct.
Sourcefn get_base_object_mut(&mut self) -> &mut Object
fn get_base_object_mut(&mut self) -> &mut Object
Get the mutable object struct.
Sourceimpl TagBlockFn for Garbage
impl TagBlockFn for Garbage
Sourcefn field_count(&self) -> usize
fn field_count(&self) -> usize
Get the number of fields.
Sourcefn field_at_index(&self, _: usize) -> TagField<'_>
fn field_at_index(&self, _: usize) -> TagField<'_>
Get the field at the given index. Panics if it is out of bounds.
Sourcefn field_at_index_mut(&mut self, _: usize) -> TagField<'_>
fn field_at_index_mut(&mut self, _: usize) -> TagField<'_>
Get the mutable field at the given index. Panics if it is out of bounds.
Sourceimpl TagFileSerializeFn for Garbage
impl TagFileSerializeFn for Garbage
Sourcefn from_tag_file(data: &[u8]) -> ErrorMessageResult<ParsedTagFile<Self>>
fn from_tag_file(data: &[u8]) -> ErrorMessageResult<ParsedTagFile<Self>>
Deserialize the data into the tag struct.
Sourcefn into_tag_file(&self) -> ErrorMessageResult<Vec<u8>>
fn into_tag_file(&self) -> ErrorMessageResult<Vec<u8>>
Serialize the tag struct into a tag file.
Sourceimpl TagSerialize for Garbage
impl TagSerialize for Garbage
Sourcefn into_tag(
&self,
data: &mut Vec<u8>,
at: usize,
struct_end: usize,
) -> ErrorMessageResult<()>
fn into_tag( &self, data: &mut Vec<u8>, at: usize, struct_end: usize, ) -> ErrorMessageResult<()>
Serialize the data into tag format, returning an error on failure (except for out-of-bounds and allocation errors which will panic).
Sourcefn from_tag(
data: &[u8],
at: usize,
struct_end: usize,
cursor: &mut usize,
) -> ErrorMessageResult<Garbage>
fn from_tag( data: &[u8], at: usize, struct_end: usize, cursor: &mut usize, ) -> ErrorMessageResult<Garbage>
Deserialize the data from tag format, returning an error on failure (except for allocation errors which will panic).
Sourcefn into_tag_cached(
&self,
data: &mut [u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<()>where
Self: Sized,
fn into_tag_cached(
&self,
data: &mut [u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<()>where
Self: Sized,
Serialize the data into tag format in little endian, returning an error on failure (except for out-of-bounds and allocation errors which will panic).
Sourcefn from_tag_cached(
data: &[u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<Self>where
Self: Sized,
fn from_tag_cached(
data: &[u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<Self>where
Self: Sized,
Deserialize the data from tag format from little endian, returning an error on failure (except for allocation errors which will panic).
impl StructuralPartialEq for Garbage