pub struct ProjectileMaterialResponse {Show 17 fields
pub flags: ProjectileMaterialResponseFlags,
pub default_response: ProjectileResponse,
pub default_effect: TagReference,
pub potential_response: ProjectileResponse,
pub potential_flags: ProjectileMaterialResponsePotentialFlags,
pub potential_skip_fraction: f32,
pub potential_between: Bounds<f32>,
pub potential_and: Bounds<f32>,
pub potential_effect: TagReference,
pub scale_effects_by: ProjectileScaleEffectsBy,
pub angular_noise: f32,
pub velocity_noise: f32,
pub detonation_effect: TagReference,
pub initial_friction: f32,
pub maximum_distance: f32,
pub parallel_friction: f32,
pub perpendicular_friction: f32,
}Fields
flags: ProjectileMaterialResponseFlagsdefault_response: ProjectileResponsedefault_effect: TagReferenceAllowed groups: Effect
potential_response: ProjectileResponsepotential_flags: ProjectileMaterialResponsePotentialFlagspotential_skip_fraction: f32potential_between: Bounds<f32>potential_and: Bounds<f32>potential_effect: TagReferenceAllowed groups: Effect
scale_effects_by: ProjectileScaleEffectsByangular_noise: f32velocity_noise: f32detonation_effect: TagReferenceAllowed groups: Effect
initial_friction: f32maximum_distance: f32parallel_friction: f32perpendicular_friction: f32Trait Implementations
Sourceimpl Clone for ProjectileMaterialResponse
impl Clone for ProjectileMaterialResponse
Sourcefn clone(&self) -> ProjectileMaterialResponse
fn clone(&self) -> ProjectileMaterialResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ProjectileMaterialResponse
impl Default for ProjectileMaterialResponse
Sourcefn default() -> ProjectileMaterialResponse
fn default() -> ProjectileMaterialResponse
Returns the “default value” for a type. Read more
Sourceimpl TagBlockFn for ProjectileMaterialResponse
impl TagBlockFn for ProjectileMaterialResponse
Sourcefn field_count(&self) -> usize
fn field_count(&self) -> usize
Get the number of fields.
Sourcefn field_at_index(&self, _: usize) -> TagField<'_>
fn field_at_index(&self, _: usize) -> TagField<'_>
Get the field at the given index. Panics if it is out of bounds.
Sourcefn field_at_index_mut(&mut self, _: usize) -> TagField<'_>
fn field_at_index_mut(&mut self, _: usize) -> TagField<'_>
Get the mutable field at the given index. Panics if it is out of bounds.
Sourceimpl TagSerialize for ProjectileMaterialResponse
impl TagSerialize for ProjectileMaterialResponse
Sourcefn into_tag(
&self,
data: &mut Vec<u8>,
at: usize,
struct_end: usize,
) -> ErrorMessageResult<()>
fn into_tag( &self, data: &mut Vec<u8>, at: usize, struct_end: usize, ) -> ErrorMessageResult<()>
Serialize the data into tag format, returning an error on failure (except for out-of-bounds and allocation errors which will panic).
Sourcefn from_tag(
data: &[u8],
at: usize,
struct_end: usize,
cursor: &mut usize,
) -> ErrorMessageResult<ProjectileMaterialResponse>
fn from_tag( data: &[u8], at: usize, struct_end: usize, cursor: &mut usize, ) -> ErrorMessageResult<ProjectileMaterialResponse>
Deserialize the data from tag format, returning an error on failure (except for allocation errors which will panic).
Sourcefn into_tag_cached(
&self,
data: &mut [u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<()>where
Self: Sized,
fn into_tag_cached(
&self,
data: &mut [u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<()>where
Self: Sized,
Serialize the data into tag format in little endian, returning an error on failure (except for out-of-bounds and allocation errors which will panic).
Sourcefn from_tag_cached(
data: &[u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<Self>where
Self: Sized,
fn from_tag_cached(
data: &[u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<Self>where
Self: Sized,
Deserialize the data from tag format from little endian, returning an error on failure (except for allocation errors which will panic).
impl StructuralPartialEq for ProjectileMaterialResponse