pub struct ScenarioCommandPoint {
pub position: Point3D,
pub surface_index: u32,
}Fields
position: Point3Dsurface_index: u32Trait Implementations
Sourceimpl Clone for ScenarioCommandPoint
impl Clone for ScenarioCommandPoint
Sourcefn clone(&self) -> ScenarioCommandPoint
fn clone(&self) -> ScenarioCommandPoint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ScenarioCommandPoint
impl Default for ScenarioCommandPoint
Sourcefn default() -> ScenarioCommandPoint
fn default() -> ScenarioCommandPoint
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ScenarioCommandPoint
impl PartialEq for ScenarioCommandPoint
Sourcefn eq(&self, other: &ScenarioCommandPoint) -> bool
fn eq(&self, other: &ScenarioCommandPoint) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TagBlockFn for ScenarioCommandPoint
impl TagBlockFn for ScenarioCommandPoint
Sourcefn field_count(&self) -> usize
fn field_count(&self) -> usize
Get the number of fields.
Sourcefn field_at_index(&self, _: usize) -> TagField<'_>
fn field_at_index(&self, _: usize) -> TagField<'_>
Get the field at the given index. Panics if it is out of bounds.
Sourcefn field_at_index_mut(&mut self, _: usize) -> TagField<'_>
fn field_at_index_mut(&mut self, _: usize) -> TagField<'_>
Get the mutable field at the given index. Panics if it is out of bounds.
Sourceimpl TagSerialize for ScenarioCommandPoint
impl TagSerialize for ScenarioCommandPoint
Sourcefn into_tag(
&self,
data: &mut Vec<u8>,
at: usize,
struct_end: usize,
) -> ErrorMessageResult<()>
fn into_tag( &self, data: &mut Vec<u8>, at: usize, struct_end: usize, ) -> ErrorMessageResult<()>
Serialize the data into tag format, returning an error on failure (except for out-of-bounds and allocation errors which will panic).
Sourcefn from_tag(
data: &[u8],
at: usize,
struct_end: usize,
cursor: &mut usize,
) -> ErrorMessageResult<ScenarioCommandPoint>
fn from_tag( data: &[u8], at: usize, struct_end: usize, cursor: &mut usize, ) -> ErrorMessageResult<ScenarioCommandPoint>
Deserialize the data from tag format, returning an error on failure (except for allocation errors which will panic).
Sourcefn into_tag_cached(
&self,
data: &mut [u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<()>where
Self: Sized,
fn into_tag_cached(
&self,
data: &mut [u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<()>where
Self: Sized,
Serialize the data into tag format in little endian, returning an error on failure (except for out-of-bounds and allocation errors which will panic).
Sourcefn from_tag_cached(
data: &[u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<Self>where
Self: Sized,
fn from_tag_cached(
data: &[u8],
at: usize,
struct_end: usize,
) -> ErrorMessageResult<Self>where
Self: Sized,
Deserialize the data from tag format from little endian, returning an error on failure (except for allocation errors which will panic).
impl Copy for ScenarioCommandPoint
impl StructuralPartialEq for ScenarioCommandPoint