Point2D

Struct Point2D 

pub struct Point2D {
    pub x: f32,
    pub y: f32,
}
Vector used for referencing a point in 2D space.

Fields

x: f32

X value.

y: f32

Y value.

Implementations

Source

impl Point2D

pub fn distance_from_plane(&self, plane: &Plane2D) -> f32

Calculate the distance the point is from the plane.

The value is positive if the point is in front of the plane, zero if intersecting, or negative if behind.

pub fn distance_from_point_squared(&self, point: &Point2D) -> f32

Calculate the distance the point is from another point. The value is returned squared for performance.

pub fn scale(&self, by: f32) -> Point2D

Scale the vector and return the result.