pub struct Point2D {
pub x: f32,
pub y: f32,
}Expand description
Vector used for referencing a point in 2D space.
Fields
x: f32X value.
y: f32Y value.
Implementations
Sourceimpl Point2D
impl Point2D
Sourcepub fn distance_from_plane(&self, plane: &Plane2D) -> f32
pub fn distance_from_plane(&self, plane: &Plane2D) -> f32
Calculate the distance the point is from the plane.
The value is positive if the point is in front of the plane, zero if intersecting, or negative if behind.
Sourcepub fn distance_from_point_squared(&self, point: &Point2D) -> f32
pub fn distance_from_point_squared(&self, point: &Point2D) -> f32
Calculate the distance the point is from another point. The value is returned squared for performance.